@@ -3,15 +3,19 @@
 # Enables internal pre-parsed structure dumper and then dumps
 #    the parsed structure.
 use strict;
+use vars qw( $VERSION );
 use warnings;
 use lib qw( ../lib lib );
 
-our $VERSION = '0.10';
+$VERSION = '0.11';
 
 BEGIN {
     *Parse::HTTP::UserAgent::DEBUG = sub () { 1 }
 }
 
-use Parse::HTTP::UserAgent -all;
+use Parse::HTTP::UserAgent;
 
-my $pok = print Parse::HTTP::UserAgent->new( shift || die "UserAgent?\n" )->dumper;
+print Parse::HTTP::UserAgent
+        ->new( shift || die "UserAgent?\n" )
+        ->dumper
+    or die "Unable to print: $!";
