@@ -3,9 +3,8 @@ use strict;
 use warnings;
 use vars qw( $VERSION );
 use Parse::HTTP::UserAgent::Constants qw(:all);
-use constant OPERA_FAKER_EXTRA_SIZE => 4;
 
-$VERSION = '0.31';
+$VERSION = '0.32';
 
 sub _is_opera_pre {
     my($self, $moz) = @_;
@@ -19,18 +18,20 @@ sub _is_opera_post {
 
 sub _is_opera_ff { # opera faking as firefox
     my($self, $extra) = @_;
-    return $extra && @{$extra} == OPERA_FAKER_EXTRA_SIZE && $extra->[2] eq 'Opera';
+    return $extra
+            && @{$extra}    ==  OPERA_FAKER_EXTRA_SIZE
+            &&  $extra->[2] eq 'Opera';
 }
 
 sub _is_safari {
     my($self, $extra, $others) = @_;
     my $str = $self->[UA_STRING];
     # epiphany?
-    return                index( $str                   , 'Chrome'       ) != NO_IMATCH ? 0 # faker
-          :               index( $str                   , 'Android'      ) != NO_IMATCH ? 0 # faker
-          :    $extra  && index( $extra->[0]            , 'AppleWebKit'  ) != NO_IMATCH ? 1
-          : @{$others} && index( $others->[LAST_ELEMENT], 'Safari'       ) != NO_IMATCH ? 1
-          :                                                                     0
+    return                index( $str                   , 'Chrome'      ) != NO_IMATCH ? 0 # faker
+          :               index( $str                   , 'Android'     ) != NO_IMATCH ? 0 # faker
+          :    $extra  && index( $extra->[0]            , 'AppleWebKit' ) != NO_IMATCH ? 1
+          : @{$others} && index( $others->[LAST_ELEMENT], 'Safari'      ) != NO_IMATCH ? 1
+          :                                                                              0
           ;
 }
 
@@ -138,8 +139,8 @@ Parse::HTTP::UserAgent::Base::IS - Base class
 
 =head1 DESCRIPTION
 
-This document describes version C<0.31> of C<Parse::HTTP::UserAgent::Base::IS>
-released on C<29 October 2011>.
+This document describes version C<0.32> of C<Parse::HTTP::UserAgent::Base::IS>
+released on C<6 November 2011>.
 
 Internal module.
 
