@@ -3,12 +3,8 @@ use strict;
 use warnings;
 use vars qw( $VERSION );
 use Parse::HTTP::UserAgent::Constants qw(:all);
-use constant ERROR_MAXTHON_VERSION => 'Unable to extract Maxthon version from Maxthon UA-string';
-use constant ERROR_MAXTHON_MSIE    => 'Unable to extract MSIE from Maxthon UA-string';
-use constant OPERA9                => 9;
-use constant OPERA_TK_LENGTH       => 5;
 
-$VERSION = '0.31';
+$VERSION = '0.32';
 
 sub _extract_dotnet {
     my($self, @args) = @_;
@@ -163,7 +159,11 @@ sub _parse_safari {
                             :         'Safari';
     $self->[UA_VERSION_RAW] = $vx;
     $self->[UA_TOOLKIT]     = $extra ? [ split RE_SLASH, $extra->[0] ] : [];
-    $self->[UA_LANG]        = pop @{ $thing };
+    if ( $thing->[-1] && length($thing->[LAST_ELEMENT]) <= 5 ) {
+        # todo: $self->_is_lang_field($junk)
+        # in here or in _post_parse()
+        $self->[UA_LANG]    = pop @{ $thing };
+    }
     $self->[UA_OS]          = @{$thing} && length $thing->[LAST_ELEMENT] > 1
                             ? pop   @{ $thing }
                             : shift @{ $thing }
@@ -178,8 +178,8 @@ sub _parse_safari {
     }
     $self->[UA_EXTRAS]      = [ @{$thing}, @others ];
 
-    if ( length($self->[UA_OS]) == 1 ) {
-        push @{$self->[UA_EXTRAS]}, $self->[UA_EXTRAS];
+    if ( $self->[UA_OS] && length($self->[UA_OS]) == 1 ) {
+        push @{$self->[UA_EXTRAS]}, $self->[UA_OS];
         $self->[UA_OS] = undef;
     }
 
@@ -621,8 +621,8 @@ Parse::HTTP::UserAgent::Base::Parsers - Base class
 
 =head1 DESCRIPTION
 
-This document describes version C<0.31> of C<Parse::HTTP::UserAgent::Base::Parsers>
-released on C<29 October 2011>.
+This document describes version C<0.32> of C<Parse::HTTP::UserAgent::Base::Parsers>
+released on C<6 November 2011>.
 
 Internal module.
 
