@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use vars qw( $VERSION $OID @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS );
 
-$VERSION = '0.31';
+$VERSION = '0.32';
 
 use constant MINUS_ONE           => -1;
 use constant NO_IMATCH           => -1; # for index()
@@ -66,6 +66,12 @@ use constant RE_DIGIT_DOT_DIGIT  => qr{\d+[.]?\d}xms;
 use constant RE_WARN_OVERFLOW => qr{\QInteger overflow in version\E}xms;
 use constant RE_WARN_INVALID  => qr{\QVersion string .+? contains invalid data; ignoring:\E}xms;
 
+use constant ERROR_MAXTHON_VERSION  => 'Unable to extract Maxthon version from Maxthon UA-string';
+use constant ERROR_MAXTHON_MSIE     => 'Unable to extract MSIE from Maxthon UA-string';
+use constant OPERA9                 => 9;
+use constant OPERA_TK_LENGTH        => 5;
+use constant OPERA_FAKER_EXTRA_SIZE => 4;
+
 use constant LIST_ROBOTS         => qw(
     Wget
     curl
@@ -145,6 +151,15 @@ BEGIN {
             INSIDE_UNIT_TEST
             INSIDE_VERBOSE_TEST
         )],
+        error => [qw(
+            ERROR_MAXTHON_VERSION
+            ERROR_MAXTHON_MSIE
+        )],
+        opera => [qw(
+            OPERA9
+            OPERA_TK_LENGTH
+            OPERA_FAKER_EXTRA_SIZE
+        )],
     );
 
     @EXPORT_OK        = map { @{ $_ } } values %EXPORT_TAGS;
@@ -163,8 +178,8 @@ Parse::HTTP::UserAgent::Constants - Various constants
 
 =head1 DESCRIPTION
 
-This document describes version C<0.31> of C<Parse::HTTP::UserAgent::Constants>
-released on C<29 October 2011>.
+This document describes version C<0.32> of C<Parse::HTTP::UserAgent::Constants>
+released on C<6 November 2011>.
 
 Internal module
 
